# DeviceHealthDetails


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**bfd_sessions** | **int** |  | [optional] 
**bfd_sessions_up** | **int** |  | [optional] 
**board_serial_number** | **str** |  | [optional] 
**chassis_number** | **str** |  | [optional] 
**connected_vmanages** | **[str]** |  | [optional] 
**control_connections_to_vsmat** | [**DeviceHealthDetails**](DeviceHealthDetails.md) |  | [optional] 
**control_connections** | **int** |  | [optional] 
**control_connections_up** | **int** |  | [optional] 
**cpu_load** | **float** |  | [optional] 
**device_groups** | **[str]** |  | [optional] 
**device_model** | **str** |  | [optional] 
**device_type** | **str** |  | [optional] 
**expected_vsmart_connections** | **int** |  | [optional] 
**has_geo_data** | **bool** |  | [optional] 
**health** | **str** |  | [optional] 
**latitude** | **str** |  | [optional] 
**local_system_ip** | **str** |  | [optional] 
**location** | **str** |  | [optional] 
**longitude** | **str** |  | [optional] 
**memory_utilization** | **float** |  | [optional] 
**name** | **str** |  | [optional] 
**omp_peers** | **int** |  | [optional] 
**omp_peers_up** | **int** |  | [optional] 
**personality** | **str** |  | [optional] 
**qoe** | **int** |  | [optional] 
**reachability** | **str** |  | [optional] 
**site_id** | **str** |  | [optional] 
**software_version** | **str** |  | [optional] 
**system_ip** | **str** |  | [optional] 
**uptime_date** | **int** |  | [optional] 
**uuid** | **str** |  | [optional] 
**vpn_ids** | **[str]** |  | [optional] 
**vsmart_control_connections** | **int** |  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


